Skip to contents

Provides an overview analysis of 'External Collaboration'. Returns a stacked bar plot of internal and external collaboration. Additional options available to return a summary table.

Usage

external_sum(
  data,
  hrvar = "Organization",
  mingroup = 5,
  stack_colours = c("#1d327e", "#1d7e6a"),
  return = "plot"
)

external_summary(
  data,
  hrvar = "Organization",
  mingroup = 5,
  stack_colours = c("#1d327e", "#1d7e6a"),
  return = "plot"
)

Arguments

data

A Standard Person Query dataset in the form of a data frame. This must be a panel dataset where each row represents one employee per time period, with the columns PersonId and MetricDate present. If your data is already aggregated (e.g. one row per group), use the equivalent *_asis() variant of this function instead.

hrvar

String containing the name of the HR Variable by which to split metrics. Defaults to "Organization". To run the analysis on the total instead of splitting by an HR attribute, supply NULL (without quotes).

mingroup

Numeric value setting the privacy threshold / minimum group size. Defaults to 5.

stack_colours

A character vector to specify the colour codes for the stacked bar charts.

return

Character vector specifying what to return, defaults to "plot". Valid inputs are "plot" and "table".

Value

Returns a 'ggplot' object by default, where 'plot' is passed in return. When 'table' is passed, a summary table is returned as a data frame.

Examples

# Return a plot
external_sum(pq_data, hrvar = "LevelDesignation")


# Return summary table
external_sum(pq_data, hrvar = "LevelDesignation", return = "table")
#> # A tibble: 4 × 5
#>   group          Internal_hours External_hours Total Employee_Count
#>   <chr>                   <dbl>          <dbl> <dbl>          <int>
#> 1 Executive                14.1           9.11  23.2             37
#> 2 Junior IC                14.0           8.90  22.9            136
#> 3 Senior IC                14.2           8.96  23.1             87
#> 4 Senior Manager           14.0           8.81  22.8             40