Skip to contents

This function provides a week by week view of the count of the distinct people by the specified HR attribute.The default behaviour is to return a week by week heatmap bar plot.

Usage

hrvar_trend(data, hrvar = "Organization", return = "plot")

Arguments

data

A Standard Person Query dataset in the form of a data frame. This must be a panel dataset where each row represents one employee per time period, with the columns PersonId and MetricDate present.

hrvar

HR Variable by which to split metrics, defaults to "Organization" but accepts any character vector, e.g. "LevelDesignation". If a vector with more than one value is provided, the HR attributes are automatically concatenated.

return

String specifying what to return. This must be one of the following strings:

  • "plot"

  • "table"

See Value for more information.

Value

A different output is returned depending on the value passed to the return argument:

  • "plot": 'ggplot' object containing a bar plot.

  • "table": data frame containing a count table.

Examples

# Return a bar plot
hrvar_trend(pq_data, hrvar = "LevelDesignation")


# Return a summary table
hrvar_trend(pq_data, hrvar = "LevelDesignation", return = "table")
#> # A tibble: 4 × 24
#>   group         `2024-04-28` `2024-05-05` `2024-05-12` `2024-05-19` `2024-05-26`
#>   <chr>                <dbl>        <dbl>        <dbl>        <dbl>        <dbl>
#> 1 Executive               37           37           37           37           37
#> 2 Junior IC              136          136          136          136          136
#> 3 Senior IC               87           87           87           87           87
#> 4 Senior Manag…           40           40           40           40           40
#> # ℹ 18 more variables: `2024-06-02` <dbl>, `2024-06-09` <dbl>,
#> #   `2024-06-16` <dbl>, `2024-06-23` <dbl>, `2024-06-30` <dbl>,
#> #   `2024-07-07` <dbl>, `2024-07-14` <dbl>, `2024-07-21` <dbl>,
#> #   `2024-07-28` <dbl>, `2024-08-04` <dbl>, `2024-08-11` <dbl>,
#> #   `2024-08-18` <dbl>, `2024-08-25` <dbl>, `2024-09-01` <dbl>,
#> #   `2024-09-08` <dbl>, `2024-09-15` <dbl>, `2024-09-22` <dbl>,
#> #   `2024-09-29` <dbl>