Returns a line chart showing the change in employee count over time. Part of a data validation process to check for unusual license growth / declines over time.
hr_trend(data, return = "plot")A different output is returned depending on the value passed to the return
argument:
"plot": ggplot object. A line plot showing employee count over time.
"table": data frame containing a summary table.
A Standard Person Query dataset in the form of a data frame.
This must be a panel dataset where each row represents one employee
per time period, with the columns PersonId and MetricDate present.
String specifying what to return. This must be one of the following strings:
"plot"
"table"
See Value for more information.
Other Visualization:
afterhours_dist(),
afterhours_fizz(),
afterhours_line(),
afterhours_rank(),
afterhours_summary(),
afterhours_trend(),
collaboration_area(),
collaboration_dist(),
collaboration_fizz(),
collaboration_line(),
collaboration_rank(),
collaboration_sum(),
collaboration_trend(),
create_bar(),
create_bar_asis(),
create_boxplot(),
create_bubble(),
create_dist(),
create_fizz(),
create_inc(),
create_line(),
create_line_asis(),
create_period_scatter(),
create_radar(),
create_rank(),
create_rogers(),
create_sankey(),
create_scatter(),
create_stacked(),
create_survival(),
create_tracking(),
create_trend(),
email_dist(),
email_fizz(),
email_line(),
email_rank(),
email_summary(),
email_trend(),
external_dist(),
external_fizz(),
external_line(),
external_rank(),
external_sum(),
hrvar_count(),
hrvar_trend(),
keymetrics_scan(),
meeting_dist(),
meeting_fizz(),
meeting_line(),
meeting_rank(),
meeting_summary(),
meeting_trend(),
one2one_dist(),
one2one_fizz(),
one2one_freq(),
one2one_line(),
one2one_rank(),
one2one_sum(),
one2one_trend()
Other Data Validation:
check_query(),
extract_hr(),
flag_ch_ratio(),
flag_em_ratio(),
flag_extreme(),
flag_outlooktime(),
hrvar_count(),
hrvar_count_all(),
hrvar_trend(),
identify_churn(),
identify_holidayweeks(),
identify_inactiveweeks(),
identify_nkw(),
identify_outlier(),
identify_privacythreshold(),
identify_shifts(),
identify_tenure(),
track_HR_change(),
validation_report()
# Return plot
hr_trend(pq_data)
# Return summary table
hr_trend(pq_data, return = "table")
Run the code above in your browser using DataLab